import sys
import io
import os
from collections import OrderedDict

class Attribute(object):
	def __init__(self, name, value = None):
		self.name = name
		self.values = []
		if value is not None:
			if type(value) is list:
				self.values = value
			else:
				self.values.append(value)

	def addValue(self, value):
		if type(value) is list:
			self.values.extend(value)
		else:
			self.values.append(value)

	def setValue(self, value):
		if type(value) is list:
			self.values = value
		else:
			self.values = [ value ]
			
	def getValue(self):
		if len(self.values) == 1:
			return self.values[0]
		else:
			return self.values

	def _print(self, indent, format_str="%s", file_desc=sys.stdout):
		tabs = "".rjust(indent, '\t')
		def formatter(g):
			return format_str % g
		formatted = map(formatter, list(filter(lambda x: x is not None, self.values)))
		file_desc.write("%s%s = %s;\n" % (tabs, self.name, ", ".join(formatted)))

class RawAttribute(Attribute):
	def __init__(self, name):
		Attribute.__init__(self, name)

	def _print(self, indent, file_desc=sys.stdout):
		tabs = "".rjust(indent, '\t')
		file_desc.write("%s%s\n" % (tabs, self.name))
	
class StringAttribute(Attribute):
	def _print(self, indent, file_desc=sys.stdout):
		super(self.__class__, self)._print(indent, "\"%s\"", file_desc=file_desc)
	
class GpioAttribute(Attribute):
	def __init__(self, name, value = None):
		Attribute.__init__(self, name)
		self.values = [ 0, 0, 0, 0 ]
		if value is not None:
			if type(value) is list:
				self.values = value
			else:
				self.values[0] = value

	def _print(self, indent, format_str="<&gpio %s %s>", file_desc=sys.stdout):
		tabs = "".rjust(indent, '\t')
		def formatter(g):
			if g == 0:
				return "< 0 >"
			return format_str % g
		formatted = map(formatter, list(filter(lambda x: x is not None, self.values)))
		file_desc.write("%s%s = %s;\n" % (tabs, self.name, ", ".join(formatted)))
		
class IntAttribute(Attribute):
	def _print(self, indent, file_desc=sys.stdout):
		super(self.__class__, self)._print(indent, "< %d >", file_desc=file_desc)
		
class AddrAttribute(Attribute):
	def _print(self, indent, file_desc=sys.stdout):
		super(self.__class__, self)._print(indent, "< &%s >", file_desc=file_desc)

class HexAttribute(Attribute):
	def _print(self, indent, file_desc=sys.stdout):
		super(self.__class__, self)._print(indent, "< 0x%x >", file_desc=file_desc)
		
class SymbolAttribute(Attribute):
	def _print(self, indent, file_desc=sys.stdout):
		super(self.__class__, self)._print(indent, "< %s >", file_desc=file_desc)
		
class BooleanAttribute(Attribute):
	def _print(self, indent, file_desc=sys.stdout):
		tabs = "".rjust(indent, '\t')
		if self.values[0]:
			file_desc.write("%s%s;\n" % (tabs, self.name))

class DmaSingle(Attribute):
	def __init__(self, name, base, offset):
		Attribute.__init__(self, name, (base, offset))

	def _print(self, indent, file_desc=sys.stdout):
		super(self.__class__, self)._print(indent, "< %s 0x%x >", file_desc=file_desc)
		


		
				
		
			
			
		
