import sys
import io
from datetime import datetime
from device import Device
from dtobject import *
from pin import *

class DtsFile(DtObject):
	"""
	Create a new Device Tree Souce file for an overlay.

	Args:
		filename: ( str )
			File filename this object will be written to

	Returns:
		DtsFile: A new DtsFile object

	"""

	def __init__(self, filename="stdout"):
		DtObject.__init__(self, None, filename)
		self.addAttribute(BooleanAttribute("/dts-v1/", True))
		self.addAttribute(BooleanAttribute("/plugin/", True))

	def save(self):
		if self.name == "stdout" or self.name == "-":
			self.output_file = sys.stdout
		else:
			self.output_file = open(self.name, "w")

		self.output_file.write('''//__dtbocreator_dts__
/*
	Overlay source file generated with "DTBOverlayCreator" on %s.
	DO NOT EDIT THIS FILE!!!
*/
''' % datetime.now())

		for aname, a in self.attributes.items():
			a._print(0, file_desc=self.output_file)
		for oname, o in self.objects.items():
			o._print(0, file_desc=self.output_file)

		self.output_file.close()

class Overlay(Device):
	"""
	Create a new top-level Overlay object.
	This object should only be added to a :obj:`DtsFile` object.

	Args:
		parent: (:obj:`DtsFile`)
			The DtsFile that will contain this Overlay
		name: (str)
			The name of the overlay.
			Example: "My Overlay"
		compatible: (str)
			A list of compatible architecures.
				Example: ["nvidia,p3449-0000-b00+p3448-0000-b00", "nvidia,p3449-0000-a02+p3448-0000-a02"]

			This is also the default.

	Returns:
		Overlay: A new Overlay object which has already been ded to the parent :obj:`DtsFile`

	"""
	def __init__(self, parent, name, compatible):
		Device.__init__(self, parent, "/")
		self.addAttribute(StringAttribute("overlay-name", name))
		self.addAttribute(StringAttribute("compatible", compatible))
		pm = PinMux(self, "pinmux")
		self.addObject(pm)
		
	def addFragment(self, fragment):
		"""
		Add a fragment to this overlay
		
		Args:
			fragment: (:obj:`Fragment`)
				The fragment objject to add.
		"""
		self.addObject(fragment)

	def getPinMux(self):
		return self.getObject("fragment@pinmux")
