from ..dtobject import *
from ..fragment import *
from ..attribute import *
from ..device import *
from ..overlay import *
from ..pin import *
import SPIDefaultPins

class SPIMasterController(Fragment):
	def __init__(self, parent, name, target=None):
		Fragment.__init__(self, parent, name, target)
		self.role = "master"
		self.addAttribute(StringAttribute("status", "okay"))
		ps = Device(self, "prod-settings")
		ps.addAttribute(StringAttribute("status", "disabled"))
		self.getDtsFile().addAttribute(RawAttribute("#include \"tegra-gpio.h\""))
		
	def addSlave(self, slave):
		self.addObject(slave)
		
	def setNumCS(self, numcs):
		self.addAttribute(IntAttribute("num-cs", numcs))
		
	def setPollingMode(self, mode):
		self.addAttribute(BooleanAttribute("nvidia,polling-mode", mode))
		
	def setCSGPIO(self, register, gpio_tuple):
		csgpios = self.getAttribute("cs-gpios")
		if csgpios is None:
			csgpios = GpioAttribute("cs-gpios")
			self.addAttribute(csgpios)
		csgpios.values[register] = gpio_tuple
		self.setNumCS(2)
		
	def setDefaultPins(self):
		ovl = self.getParent(Overlay)
		pinmux = ovl.getPinMux()
		target = self.getAttributeValue("target")
		SPIDefaultPins.setDefaultPins(target, self.role, pinmux)

class SPISlaveController(SPIMasterController):
	def __init__(self, parent, name, target=None):
		SPIMasterController.__init__(self, parent, name, target)
		self.role = "slave"
		self.addAttribute(StringAttribute("compatible", "nvidia,tegra210-spi-slave"))
		target = self.getAttributeValue("target")
		if target == "spi0":
			self.addAttribute(DmaSingle("nvidia,dma-request-selector", "&apbdma", 0x0f))
		else:
			self.addAttribute(DmaSingle("nvidia,dma-request-selector", "&apbdma", 0x10))
		
		self.addAttribute(BooleanAttribute("nvidia,clock-always-on", True))
		self.addAttribute(IntAttribute("nvidia,tx-trigger-words", 0))
