from ..dtobject import *
from ..fragment import *
from ..attribute import *
from ..device import *
from ..overlay import *
from ..pin import *

class SPIDeviceSPIDEV(Device):
	def __init__(self, parent, name, reg=0, max_frequency=33000000, compatible="spidev", status="okay"):
		Device.__init__(self, parent, name)
		self.addAttribute(StringAttribute("compatible", compatible))
		self.addAttribute(StringAttribute("status", status))
		self.addAttribute(HexAttribute("reg", reg))
		self.addAttribute(IntAttribute("spi-max-frequency", max_frequency))
		cd = Device(self, "controller-data")
		cd.addAttribute(BooleanAttribute("nvidia,enable-hw-based-cs", True))

	def setCSGPIO(self, gpio_tuple):
		reg = self.getAttribute("reg").getValue()
		self.parent.setCSGPIO(reg, gpio_tuple)
		cd = self.getObject("controller-data")
		self.delControllerAttribute("nvidia,enable-hw-based-cs")
		
	def addControllerAttribute(self, name, value):
		cd = self.getObject("controller-data")
		if type(value) is bool:
			cd.addAttribute(BooleanAttribute(name, value))
		elif type(value) is int:
			cd.addAttribute(HexAttribute(name, value))
		else:
			cd.addAttribute(name, value)

	def delControllerAttribute(self, name):
		cd = self.getObject("controller-data")
		cd.delAttribute(name)
